# Starcount - GitHub CLI

Python package to interact with GitHub and retrieve data.

- commands:

Count all stars of all repos of yourself, a specified user or an organization.

Allow a nicely printed format as default.

Modify your user description by adding a tea emoji and a heart.

Set your user status (top-right when clicking on username):
emoji and status message.

- Focus points:

Focus on usability and clarity with Typer for end-user

Integrate best practices about linting, CI/CD, documentation, package management
and pypi deployment.

- TODO :

Print out details about yourself, a user or organization. 

Allow for output in JSON.

- project infos:

Source Code: https://github.com/adnene-guessoum/Github_cli

Documentation: https://adnene-guessoum.github.io/Github_cli/
